==> jupyterlab-dbaccess-0.1.1.tgz: package/lib/index.js <==
import { ILayoutRestorer } from '@jupyterlab/application';
import { ICommandPalette } from '@jupyterlab/apputils';
import { IEditorServices } from '@jupyterlab/codeeditor';
import { LabIcon } from '@jupyterlab/ui-components';
// import { find } from '@lumino/algorithm';
// import editorIconSVGstr from '../style/icon/jupyter_snippeteditoricon.svg';
import codeSnippetIconSVGstr from '../style/icon/jupyter_snippeticon.svg';
// import { CodeSnippetInputDialog } from './CodeSnippetInputDialog';
import { CodeSnippetWidget } from './CodeSnippetWidget';
// import { CodeSnippetContentsService } from './CodeSnippetContentsService';
// import {
//   CodeSnippetEditor,
// } from './CodeSnippetEditor';
const CODE_SNIPPET_EXTENSION_ID = 'code-snippet-extension';
/**
 * Snippet Editor Icon
 */
// const editorIcon = new LabIcon({
//   name: 'custom-ui-compnents:codeSnippetEditorIcon',
//   svgstr: editorIconSVGstr
// });
/**
 * Snippet Icon
 */
const codeSnippetIcon = new LabIcon({
    name: 'custom-ui-compnents:codeSnippetIcon',
    svgstr: codeSnippetIconSVGstr
});
/**
 * Initialization data for the code_snippets extension.
 */
const code_snippet_extension = {
    id: CODE_SNIPPET_EXTENSION_ID,
    autoStart: true,
    requires: [ICommandPalette, ILayoutRestorer, IEditorServices],
    activate: activateCodeSnippet
};
function activateCodeSnippet(app, palette, restorer, editorServices) {
    console.log('JupyterLab extension code-snippets is activated!12345');
    const getCurrentWidget = () => {
        return app.shell.currentWidget;
    };
    const codeSnippetWidget = new CodeSnippetWidget(getCurrentWidget, app, editorServices);
    codeSnippetWidget.id = CODE_SNIPPET_EXTENSION_ID;
    codeSnippetWidget.title.icon = codeSnippetIcon;
    codeSnippetWidget.title.caption = 'Code Snippet Explorer';
    // 从snippets文件夹获取json文件
    // const contentsService = CodeSnippetContentsService.getInstance();
    // contentsService.save('snippets', { type: 'directory' });
    restorer.add(codeSnippetWidget, CODE_SNIPPET_EXTENSION_ID);
    // Rank has been chosen somewhat arbitrarily to give priority to the running
    // sessions widget in the sidebar.
    app.shell.add(codeSnippetWidget, 'left', { rank: 900 });
}
export default code_snippet_extension;

==> jupyterlab-dbaccess-0.1.4.tgz: package/lib/index.js <==
import { ILayoutRestorer } from '@jupyterlab/application';
import { ICommandPalette } from '@jupyterlab/apputils';
import { IEditorServices } from '@jupyterlab/codeeditor';
import { LabIcon } from '@jupyterlab/ui-components';
// import { find } from '@lumino/algorithm';
// import editorIconSVGstr from '../style/icon/jupyter_snippeteditoricon.svg';
import codeSnippetIconSVGstr from '../style/icon/jupyter_snippeticon.svg';
// import { CodeSnippetInputDialog } from './CodeSnippetInputDialog';
import { CodeSnippetWidget } from './CodeSnippetWidget';
// import { CodeSnippetContentsService } from './CodeSnippetContentsService';
// import {
//   CodeSnippetEditor,
// } from './CodeSnippetEditor';
const CODE_SNIPPET_EXTENSION_ID = 'code-dataset-extension';
/**
 * Snippet Editor Icon
 */
// const editorIcon = new LabIcon({
//   name: 'custom-ui-compnents:codeSnippetEditorIcon',
//   svgstr: editorIconSVGstr
// });
/**
 * Snippet Icon
 */
const codeSnippetIcon = new LabIcon({
    name: 'custom-ui-compnents:codeSnippetIcon',
    svgstr: codeSnippetIconSVGstr
});
/**
 * Initialization data for the code_snippets extension.
 */
const code_snippet_extension = {
    id: CODE_SNIPPET_EXTENSION_ID,
    autoStart: true,
    requires: [ICommandPalette, ILayoutRestorer, IEditorServices],
    activate: activateCodeSnippet
};
function activateCodeSnippet(app, palette, restorer, editorServices) {
    console.log('JupyterLab extension code-snippets is activated!12345');
    const getCurrentWidget = () => {
        return app.shell.currentWidget;
    };
    const codeDatasetWidget = new CodeSnippetWidget(getCurrentWidget, app, editorServices);
    codeDatasetWidget.id = CODE_SNIPPET_EXTENSION_ID;
    codeDatasetWidget.title.icon = codeSnippetIcon;
    codeDatasetWidget.title.caption = 'Code Dataset Explorer';
    // 从snippets文件夹获取json文件
    // const contentsService = CodeSnippetContentsService.getInstance();
    // contentsService.save('snippets', { type: 'directory' });
    restorer.add(codeDatasetWidget, CODE_SNIPPET_EXTENSION_ID);
    // Rank has been chosen somewhat arbitrarily to give priority to the running
    // sessions widget in the sidebar.
    app.shell.add(codeDatasetWidget, 'left', { rank: 800 });
}
export default code_snippet_extension;
